@@ -52,6 +52,14 @@ inline void* LoadSharedLibrary( std::string unixPrefix, std::string libraryName,
   {
           std::cerr << ::dlerror( ) << std::endl;
   }
+#elif defined(__FreeBSD__)
+        tstring freebsdName = unixPrefix;
+        freebsdName += libraryName += ".so";
+        void* fileHandle = ::dlopen( freebsdName.c_str( ), RTLD_NOW );
+        if( !quiet && !fileHandle )
+        {
+                std::cerr << ::dlerror( ) << std::endl;
+        }
 #else
         #error "unsupported platform"
 #endif
