@@ -14,10 +14,14 @@
  * limitations under the License.
  * ************************************************************************/
 
+#ifdef _MSC_VER
+#pragma warning(disable : 4996)
+#endif
 
 #pragma once
 #if !defined( AMD_CLFFT_generator_stockham_H )
 #define AMD_CLFFT_generator_stockham_H
+#include <stdio.h>
 #include "private.h"
 #include "repo.h"
 #include "plan.h"
